@@ -7,7 +7,7 @@ pub enum FxError {
     Io(String),
     Dirs(String),
     GetItem,
-    OpenItem,
+    OpenItem(String),
     OpenNewWindow(String),
     Yaml(String),
     WalkDir(String),
@@ -33,7 +33,7 @@ impl std::fmt::Display for FxError {
             FxError::Io(s) => s.to_owned(),
             FxError::Dirs(s) => s.to_owned(),
             FxError::GetItem => "Error: Cannot get item info".to_owned(),
-            FxError::OpenItem => "Error: Cannot open item".to_owned(),
+            FxError::OpenItem(s) => s.to_owned(),
             FxError::OpenNewWindow(s) => s.to_owned(),
             FxError::Yaml(s) => s.to_owned(),
             FxError::WalkDir(s) => s.to_owned(),
