@@ -1,7 +1,8 @@
+
 use super::config::{make_config_if_not_exists, CONFIG_FILE};
 use super::errors::FxError;
 use super::functions::*;
-use super::layout::Split;
+use super::layout::{Split, PreviewType};
 use super::nums::*;
 use super::op::*;
 use super::session::*;
@@ -1629,11 +1630,15 @@ fn _run(mut state: State, session_path: PathBuf) -> Result<(), FxError> {
                 }
                 //If you use kitty, you must clear the screen by the escape sequence or the previewed image remains.
                 if state.layout.is_kitty && state.layout.preview {
-                    print!("{}", CLRSCR);
-                    state.clear_and_show_headline();
-                    state.list_up();
-                    state.move_cursor(state.layout.y);
-                    screen.flush()?;
+                    if let Ok(item) = state.get_item() {
+                        if item.preview_type == Some(PreviewType::Image) {
+                            print!("{}", CLRSCR);
+                            state.clear_and_show_headline();
+                            state.list_up();
+                            state.move_cursor(state.layout.y);
+                            screen.flush()?;
+                        }
+                    }
                 }
             }
             Event::Resize(column, row) => {
@@ -1690,20 +1695,3 @@ fn _run(mut state: State, session_path: PathBuf) -> Result<(), FxError> {
     info!("===FINISH===");
     Ok(())
 }
-
-#[cfg(test)]
-mod tests {
-    use super::*;
-
-    #[test]
-    fn zoxide_test() {
-        let output = std::process::Command::new("zoxide")
-            .args(["query", "felix"])
-            .output()
-            .unwrap();
-        let stdout = std::str::from_utf8(&output.stdout).unwrap().trim();
-        println!("{stdout}");
-        let path = PathBuf::from(stdout);
-        println!("{:?}", path.canonicalize());
-    }
-}
