@@ -1,6 +1,5 @@
 use super::errors::FxError;
 use super::layout::Split;
-use super::state::FX_CONFIG_DIR;
 use serde::{Deserialize, Serialize};
 use std::fs::read_to_string;
 use std::path::Path;
@@ -26,14 +25,17 @@ pub enum SortKey {
     Time,
 }
 
-pub fn read_session() -> Result<Session, FxError> {
-    let mut session =
-        dirs::config_dir().ok_or_else(|| FxError::Dirs("Cannot read config dir.".to_string()))?;
-    session.push(FX_CONFIG_DIR);
-    session.push(SESSION_FILE);
-    let session = read_to_string(session.as_path())?;
-    match serde_yaml::from_str(&session) {
-        Ok(de) => Ok(de),
+pub fn read_session(session_path: &Path) -> Result<Session, FxError> {
+    match read_to_string(session_path) {
+        Ok(s) => match serde_yaml::from_str(&s) {
+            Ok(de) => Ok(de),
+            Err(_) => Ok(Session {
+                sort_by: SortKey::Name,
+                show_hidden: true,
+                preview: Some(false),
+                split: Some(Split::Vertical),
+            }),
+        },
         Err(_) => Ok(Session {
             sort_by: SortKey::Name,
             show_hidden: true,
@@ -44,6 +46,6 @@ pub fn read_session() -> Result<Session, FxError> {
 }
 
 pub fn make_session(session_file: &Path) -> Result<(), FxError> {
-    std::fs::write(&session_file, SESSION_EXAMPLE)?;
+    std::fs::write(session_file, SESSION_EXAMPLE)?;
     Ok(())
 }
