@@ -25,14 +25,14 @@ use std::process::{Command, ExitStatus, Stdio};
 use std::time::UNIX_EPOCH;
 use syntect::highlighting::{Theme, ThemeSet};
 
-#[cfg(target_family = "unix")]
-use std::os::unix::fs::PermissionsExt;
-#[cfg(target_family = "unix")]
-use std::os::unix::fs::MetadataExt;
 #[cfg(target_family = "unix")]
 use nix::sys::stat::Mode;
 #[cfg(target_family = "unix")]
 use nix::unistd::{Gid, Uid};
+#[cfg(target_family = "unix")]
+use std::os::unix::fs::MetadataExt;
+#[cfg(target_family = "unix")]
+use std::os::unix::fs::PermissionsExt;
 
 pub const FELIX: &str = "felix";
 pub const BEGINNING_ROW: u16 = 3;
@@ -1708,11 +1708,11 @@ fn in_groups(gid: u32) -> bool {
 
 #[cfg(test)]
 mod tests {
+    use super::*;
+
     use devtimer::run_benchmark;
     use rayon::prelude::{IntoParallelIterator, ParallelIterator};
 
-    use super::*;
-
     fn bench_update1() -> Result<(), FxError> {
         let mut dir_v = Vec::new();
         let mut file_v = Vec::new();
@@ -1750,8 +1750,13 @@ mod tests {
 
     #[test]
     fn test_has_write_permission() {
+        // chmod to 444 and check if it's read-only
         let p = std::path::PathBuf::from("./testfiles/permission_test");
+        let _status = std::process::Command::new("chmod").args(["444", "./testfiles/permission_test"]).status().unwrap();
         assert!(!has_write_permission(p.as_path()).unwrap());
+        let _status = std::process::Command::new("chmod").args(["755", "./testfiles/permission_test"]).status().unwrap();
+
+        // Test the home directory, which should pass
         let home_dir = dirs::home_dir().unwrap();
         assert!(has_write_permission(&home_dir).unwrap());
     }
